[−][src]Macro embed_wasm::include_wasm
Imports the generated static wasm blobs from the build output directory as generated by embed_wasm_build::compile_wasm
Imports the generated static wasm blobs from the build output directory as generated by embed_wasm_build::compile_wasm