[−][src]Crate embed_wasm
Macros
| include_wasm | Imports the generated static wasm blobs from the build output directory as generated by embed_wasm_build::compile_wasm |
Structs
| StaticLookup | Wraps a hashmap of static content generated at compile time and provides convenience functions for resolving static content given a path. |
Enums
| IndexHandling |